@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package App::Cme ;
-$App::Cme::VERSION = '1.003';
+$App::Cme::VERSION = '1.004';
 use strict;
 use warnings;
 use 5.10.1;
@@ -31,7 +31,7 @@ App::Cme - Check or edit configuration data with Config::Model
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 AUTHOR
 
@@ -150,8 +150,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://github.com/dod38fr/app-cme>
+L<http://github.com/dod38fr/cme-perl>
 
-  git clone git://github.com/dod38fr/app-cme.git
+  git clone https://github.com/dod38fr/cme-perl.git
 
 =cut
