@@ -10,7 +10,7 @@
 # ABSTRACT: Dump the configuration of an application
 
 package App::Cme::Command::dump ;
-$App::Cme::Command::dump::VERSION = '1.003';
+$App::Cme::Command::dump::VERSION = '1.004';
 use strict;
 use warnings;
 use 5.10.1;
@@ -32,8 +32,7 @@ sub opt_spec {
             "dumptype=s" => "Dump all values (full) or only preset values or customized values",
             {
                 regex => qr/^(?:full|custom|preset)$/,
-                required => 1,
-                #default => 'custom'
+                default => 'custom'
             }
         ],
         $class->global_options,
@@ -43,7 +42,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application]  [ config_file | ~~ ] [ -dumptype full|custom|preset ]";
+  return "$desc [application]  [ config_file | ~~ ] [ -dumptype full|custom|preset ] [ path ]";
 }
 
 sub description {
@@ -56,7 +55,9 @@ sub execute {
 
     my ($model, $inst, $root) = $self->init_cme($opt,$args);
 
-    my $dump_string = $root->dump_tree( mode => $opt->{dumptype} );
+    my $target_node = $root->grab(step => "@$args", type => 'node');
+
+    my $dump_string = $target_node->dump_tree( mode => $opt->{dumptype} );
     print $dump_string ;
 
 }
@@ -75,12 +76,20 @@ App::Cme::Command::dump - Dump the configuration of an application
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
-  # dump ~/.ssh/config in cme syntax (requires Config::Model::OpenSsh)
-  $ cme edit ssh
+  # dump ~/.ssh/config in cme syntax
+  # (this example requires Config::Model::OpenSsh)
+  $ cme dump ssh
+  Host:"*" -
+  Host:"*.debian.org"
+    User=dod -
+
+  # dump part of debian copyright file in cme syntax
+  # (this example requires Config::Model::OpenSsh)
+  $ cme dump ssh
   Host:"*" -
   Host:"*.debian.org"
     User=dod -
