@@ -10,7 +10,7 @@
 # ABSTRACT: Fix the configuration of an application
 
 package App::Cme::Command::fix ;
-$App::Cme::Command::fix::VERSION = '1.003';
+$App::Cme::Command::fix::VERSION = '1.004';
 use strict;
 use warnings;
 use 5.10.1;
@@ -55,7 +55,7 @@ sub execute {
 
     foreach my $path (@fix_from) {
         my $node_to_fix = $inst->config_root->grab($path);
-        my $msg = "Fixing ".$inst->name." configuration";
+        my $msg = "cme: running fix on ".$inst->name." configuration";
         $msg .= "from node", $node_to_fix->name if $path;
         say $msg. "..." unless $opt->{quiet};
         $node_to_fix->apply_fixes($opt->{fix_filter});
@@ -78,7 +78,7 @@ App::Cme::Command::fix - Fix the configuration of an application
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
